/*
	This file is distributed under the terms of the GNU Public License, version 2.
	
	Copyright (c) Stijn Buys, 2009
*/

#include <windows.h>
#include <wingdi.h>

#include "GL/gl.h"

#include "context.h"

namespace glock {

Context::Context(HWND handle)
{
	context_handle = handle;
	
	RECT window_size;
	GetClientRect(context_handle, &window_size);
	
	context_width = window_size.right - window_size.left;
	context_height =  window_size.bottom - window_size.top;
	
	PIXELFORMATDESCRIPTOR pixelformat;
	ZeroMemory(&pixelformat, sizeof pixelformat);
	pixelformat.nSize = sizeof pixelformat;
	pixelformat.nVersion = 1;
	pixelformat.dwFlags = PFD_SUPPORT_OPENGL | PFD_DOUBLEBUFFER | PFD_DRAW_TO_WINDOW;
	pixelformat.iPixelType = PFD_TYPE_RGBA;
	pixelformat.cColorBits = 24;
		
	context_device = GetDC(handle);	
	int i = ChoosePixelFormat(context_device, &pixelformat);
	SetPixelFormat(context_device, i, &pixelformat);
	
	context_wgl = wglCreateContext(context_device);
	wglMakeCurrent(context_device, context_wgl);
	
	reset();
}

Context::~Context()
{
	// delete wgl context
	wglMakeCurrent(0, 0);
	wglDeleteContext(context_wgl);
	
	// release the device context
	ReleaseDC(context_handle, context_device);
}

void Context::swap_buffers()
{
	SwapBuffers(context_device);
}

void Context::reset()
{
	// set viewport
	glViewport(0, 0, context_width, context_height);

	// set orthogonal projection
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	glOrtho(0, context_width, context_height, 0, -4.0f, 4.0f);
	
	// set clear color
	glClearColor(0.0f, 0.0f, 0.0f, 1.0f);
	
	// load identity matrix
	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();

}

} // namespace glock

